'use strict';

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _trim = require('trim');

var _trim2 = _interopRequireDefault(_trim);

var _nodeDirwalker = require('node-dirwalker');

var _nodeDirwalker2 = _interopRequireDefault(_nodeDirwalker);

var _confirmCli = require('confirm-cli');

var _confirmCli2 = _interopRequireDefault(_confirmCli);

var _safe = require('colors/safe');

var _safe2 = _interopRequireDefault(_safe);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var files = gatherFiles(function (files) {
  listFiles(files);

  (0, _confirmCli2.default)("Are you sure you want to continue?", yes, no);
  function yes() {
    console.log('Stripping...');
    files.forEach(function (file) {
      return processFile(file);
    });
  }
  function no() {
    console.log("Aborted");
  }
});

function gatherFiles(callback) {
  var walker = (0, _nodeDirwalker2.default)({
    ignoreFiles: ['.gitignore'],
    defaultIgnore: ['node_modules/', '.git', '.hg', '.svn', 'CVS']
  });

  var files = [];
  walker.on('entry', function (entry) {
    return fileFilter(files, entry);
  }).on('error', function (err) {
    return handleError(err);
  }).on('close', function () {
    return callback(files);
  });

  walker.walk('.', {
    recurse: true
  });
}

function fileFilter(files, entry) {
  if (entry.type === 'file' && validFile(entry.basename)) {
    files.push(entry.relname);
  }
}

function validFile(basename) {
  if (basename.endsWith('.html') || basename.endsWith('.css') || basename.endsWith('.scss') || basename.endsWith('.less') || basename.endsWith('.js') || basename.endsWith('.jsx') || basename.startsWith('.')) {
    return true;
  }

  return false;
}

function listFiles(files) {
  console.log("Found " + files.length + " files:\n");
  files.forEach(function (file) {
    console.log("=>", _safe2.default.red(file));
  });
  console.log("");
}

function processFile(filePath) {
  _fs2.default.readFile('./' + filePath, { encoding: 'utf8' }, function (err, contents) {
    if (err) {
      handleError(err);
    }

    writeFile(filePath, stripWhitespace(contents));
  });
}

var matchNewLines = new RegExp(/(.*)(\r?\n)/g);
function stripWhitespace(contents) {
  var line = void 0;
  var fixedContents = '';
  while (line = matchNewLines.exec(contents)) {
    fixedContents += _trim2.default.right(line[1]) + line[2];
  }

  return fixedContents;
}

function writeFile(filePath, fixedContents) {
  _fs2.default.writeFile('./' + filePath, fixedContents, function (err) {
    if (err) {
      handleError(err);
    }

    console.log('Done: ' + filePath);
  });
}

function handleError(err) {
  console.error(err);
  process.exit();
}